# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['LoadBalancerInternetArgs', 'LoadBalancerInternet']

@pulumi.input_type
class LoadBalancerInternetArgs:
    def __init__(__self__, *,
                 app_id: pulumi.Input[str],
                 internets: pulumi.Input[Sequence[pulumi.Input['LoadBalancerInternetInternetArgs']]],
                 internet_slb_id: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a LoadBalancerInternet resource.
        :param pulumi.Input[str] app_id: The target application ID that needs to be bound to the SLB.
        :param pulumi.Input[Sequence[pulumi.Input['LoadBalancerInternetInternetArgs']]] internets: The bound private network SLB. See the following `Block internet`.
        :param pulumi.Input[str] internet_slb_id: The internet SLB ID.
        """
        pulumi.set(__self__, "app_id", app_id)
        pulumi.set(__self__, "internets", internets)
        if internet_slb_id is not None:
            pulumi.set(__self__, "internet_slb_id", internet_slb_id)

    @property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Input[str]:
        """
        The target application ID that needs to be bound to the SLB.
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "app_id", value)

    @property
    @pulumi.getter
    def internets(self) -> pulumi.Input[Sequence[pulumi.Input['LoadBalancerInternetInternetArgs']]]:
        """
        The bound private network SLB. See the following `Block internet`.
        """
        return pulumi.get(self, "internets")

    @internets.setter
    def internets(self, value: pulumi.Input[Sequence[pulumi.Input['LoadBalancerInternetInternetArgs']]]):
        pulumi.set(self, "internets", value)

    @property
    @pulumi.getter(name="internetSlbId")
    def internet_slb_id(self) -> Optional[pulumi.Input[str]]:
        """
        The internet SLB ID.
        """
        return pulumi.get(self, "internet_slb_id")

    @internet_slb_id.setter
    def internet_slb_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "internet_slb_id", value)


@pulumi.input_type
class _LoadBalancerInternetState:
    def __init__(__self__, *,
                 app_id: Optional[pulumi.Input[str]] = None,
                 internet_ip: Optional[pulumi.Input[str]] = None,
                 internet_slb_id: Optional[pulumi.Input[str]] = None,
                 internets: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerInternetInternetArgs']]]] = None):
        """
        Input properties used for looking up and filtering LoadBalancerInternet resources.
        :param pulumi.Input[str] app_id: The target application ID that needs to be bound to the SLB.
        :param pulumi.Input[str] internet_ip: Use designated public network SLBs that have been purchased to support non-shared instances.
        :param pulumi.Input[str] internet_slb_id: The internet SLB ID.
        :param pulumi.Input[Sequence[pulumi.Input['LoadBalancerInternetInternetArgs']]] internets: The bound private network SLB. See the following `Block internet`.
        """
        if app_id is not None:
            pulumi.set(__self__, "app_id", app_id)
        if internet_ip is not None:
            pulumi.set(__self__, "internet_ip", internet_ip)
        if internet_slb_id is not None:
            pulumi.set(__self__, "internet_slb_id", internet_slb_id)
        if internets is not None:
            pulumi.set(__self__, "internets", internets)

    @property
    @pulumi.getter(name="appId")
    def app_id(self) -> Optional[pulumi.Input[str]]:
        """
        The target application ID that needs to be bound to the SLB.
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "app_id", value)

    @property
    @pulumi.getter(name="internetIp")
    def internet_ip(self) -> Optional[pulumi.Input[str]]:
        """
        Use designated public network SLBs that have been purchased to support non-shared instances.
        """
        return pulumi.get(self, "internet_ip")

    @internet_ip.setter
    def internet_ip(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "internet_ip", value)

    @property
    @pulumi.getter(name="internetSlbId")
    def internet_slb_id(self) -> Optional[pulumi.Input[str]]:
        """
        The internet SLB ID.
        """
        return pulumi.get(self, "internet_slb_id")

    @internet_slb_id.setter
    def internet_slb_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "internet_slb_id", value)

    @property
    @pulumi.getter
    def internets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerInternetInternetArgs']]]]:
        """
        The bound private network SLB. See the following `Block internet`.
        """
        return pulumi.get(self, "internets")

    @internets.setter
    def internets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['LoadBalancerInternetInternetArgs']]]]):
        pulumi.set(self, "internets", value)


class LoadBalancerInternet(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[str]] = None,
                 internet_slb_id: Optional[pulumi.Input[str]] = None,
                 internets: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LoadBalancerInternetInternetArgs']]]]] = None,
                 __props__=None):
        """
        Provides an Alicloud Serverless App Engine (SAE) Application Load Balancer Attachment resource.

        For information about Serverless App Engine (SAE) Load Balancer Internet Attachment and how to use it, see [sae.LoadBalancerInternet](https://help.aliyun.com/document_detail/126360.html).

        > **NOTE:** Available in v1.164.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.sae.LoadBalancerInternet("example",
            app_id="your_application_id",
            internets=[alicloud.sae.LoadBalancerInternetInternetArgs(
                port=80,
                protocol="TCP",
                target_port=8080,
            )],
            internet_slb_id="your_internet_slb_id")
        ```

        ## Import

        The resource can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:sae/loadBalancerInternet:LoadBalancerInternet example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] app_id: The target application ID that needs to be bound to the SLB.
        :param pulumi.Input[str] internet_slb_id: The internet SLB ID.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LoadBalancerInternetInternetArgs']]]] internets: The bound private network SLB. See the following `Block internet`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: LoadBalancerInternetArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides an Alicloud Serverless App Engine (SAE) Application Load Balancer Attachment resource.

        For information about Serverless App Engine (SAE) Load Balancer Internet Attachment and how to use it, see [sae.LoadBalancerInternet](https://help.aliyun.com/document_detail/126360.html).

        > **NOTE:** Available in v1.164.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.sae.LoadBalancerInternet("example",
            app_id="your_application_id",
            internets=[alicloud.sae.LoadBalancerInternetInternetArgs(
                port=80,
                protocol="TCP",
                target_port=8080,
            )],
            internet_slb_id="your_internet_slb_id")
        ```

        ## Import

        The resource can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:sae/loadBalancerInternet:LoadBalancerInternet example <id>
        ```

        :param str resource_name: The name of the resource.
        :param LoadBalancerInternetArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(LoadBalancerInternetArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[str]] = None,
                 internet_slb_id: Optional[pulumi.Input[str]] = None,
                 internets: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LoadBalancerInternetInternetArgs']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = LoadBalancerInternetArgs.__new__(LoadBalancerInternetArgs)

            if app_id is None and not opts.urn:
                raise TypeError("Missing required property 'app_id'")
            __props__.__dict__["app_id"] = app_id
            __props__.__dict__["internet_slb_id"] = internet_slb_id
            if internets is None and not opts.urn:
                raise TypeError("Missing required property 'internets'")
            __props__.__dict__["internets"] = internets
            __props__.__dict__["internet_ip"] = None
        super(LoadBalancerInternet, __self__).__init__(
            'alicloud:sae/loadBalancerInternet:LoadBalancerInternet',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            app_id: Optional[pulumi.Input[str]] = None,
            internet_ip: Optional[pulumi.Input[str]] = None,
            internet_slb_id: Optional[pulumi.Input[str]] = None,
            internets: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LoadBalancerInternetInternetArgs']]]]] = None) -> 'LoadBalancerInternet':
        """
        Get an existing LoadBalancerInternet resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] app_id: The target application ID that needs to be bound to the SLB.
        :param pulumi.Input[str] internet_ip: Use designated public network SLBs that have been purchased to support non-shared instances.
        :param pulumi.Input[str] internet_slb_id: The internet SLB ID.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['LoadBalancerInternetInternetArgs']]]] internets: The bound private network SLB. See the following `Block internet`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _LoadBalancerInternetState.__new__(_LoadBalancerInternetState)

        __props__.__dict__["app_id"] = app_id
        __props__.__dict__["internet_ip"] = internet_ip
        __props__.__dict__["internet_slb_id"] = internet_slb_id
        __props__.__dict__["internets"] = internets
        return LoadBalancerInternet(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Output[str]:
        """
        The target application ID that needs to be bound to the SLB.
        """
        return pulumi.get(self, "app_id")

    @property
    @pulumi.getter(name="internetIp")
    def internet_ip(self) -> pulumi.Output[str]:
        """
        Use designated public network SLBs that have been purchased to support non-shared instances.
        """
        return pulumi.get(self, "internet_ip")

    @property
    @pulumi.getter(name="internetSlbId")
    def internet_slb_id(self) -> pulumi.Output[Optional[str]]:
        """
        The internet SLB ID.
        """
        return pulumi.get(self, "internet_slb_id")

    @property
    @pulumi.getter
    def internets(self) -> pulumi.Output[Sequence['outputs.LoadBalancerInternetInternet']]:
        """
        The bound private network SLB. See the following `Block internet`.
        """
        return pulumi.get(self, "internets")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['ReceiversArgs', 'Receivers']

@pulumi.input_type
class ReceiversArgs:
    def __init__(__self__, *,
                 receivers_alias: pulumi.Input[str],
                 receivers_name: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Receivers resource.
        :param pulumi.Input[str] receivers_alias: The alias of receivers. Must email address and less than 30 characters in length.
        :param pulumi.Input[str] receivers_name: The name of the resource. The length that cannot be repeated is 1-30 characters.
        :param pulumi.Input[str] description: The description of receivers and 1-50 characters in length.
        """
        pulumi.set(__self__, "receivers_alias", receivers_alias)
        pulumi.set(__self__, "receivers_name", receivers_name)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @property
    @pulumi.getter(name="receiversAlias")
    def receivers_alias(self) -> pulumi.Input[str]:
        """
        The alias of receivers. Must email address and less than 30 characters in length.
        """
        return pulumi.get(self, "receivers_alias")

    @receivers_alias.setter
    def receivers_alias(self, value: pulumi.Input[str]):
        pulumi.set(self, "receivers_alias", value)

    @property
    @pulumi.getter(name="receiversName")
    def receivers_name(self) -> pulumi.Input[str]:
        """
        The name of the resource. The length that cannot be repeated is 1-30 characters.
        """
        return pulumi.get(self, "receivers_name")

    @receivers_name.setter
    def receivers_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "receivers_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of receivers and 1-50 characters in length.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)


@pulumi.input_type
class _ReceiversState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[str]] = None,
                 receivers_alias: Optional[pulumi.Input[str]] = None,
                 receivers_name: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[int]] = None):
        """
        Input properties used for looking up and filtering Receivers resources.
        :param pulumi.Input[str] description: The description of receivers and 1-50 characters in length.
        :param pulumi.Input[str] receivers_alias: The alias of receivers. Must email address and less than 30 characters in length.
        :param pulumi.Input[str] receivers_name: The name of the resource. The length that cannot be repeated is 1-30 characters.
        :param pulumi.Input[int] status: The status of the resource. `0` means uploading, `1` means upload completed.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if receivers_alias is not None:
            pulumi.set(__self__, "receivers_alias", receivers_alias)
        if receivers_name is not None:
            pulumi.set(__self__, "receivers_name", receivers_name)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of receivers and 1-50 characters in length.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="receiversAlias")
    def receivers_alias(self) -> Optional[pulumi.Input[str]]:
        """
        The alias of receivers. Must email address and less than 30 characters in length.
        """
        return pulumi.get(self, "receivers_alias")

    @receivers_alias.setter
    def receivers_alias(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "receivers_alias", value)

    @property
    @pulumi.getter(name="receiversName")
    def receivers_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the resource. The length that cannot be repeated is 1-30 characters.
        """
        return pulumi.get(self, "receivers_name")

    @receivers_name.setter
    def receivers_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "receivers_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[int]]:
        """
        The status of the resource. `0` means uploading, `1` means upload completed.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "status", value)


class Receivers(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 receivers_alias: Optional[pulumi.Input[str]] = None,
                 receivers_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Direct Mail Receivers resource.

        For information about Direct Mail Receivers and how to use it, see [What is Direct Mail Receivers](https://www.alibabacloud.com/help/en/doc-detail/29414.htm).

        > **NOTE:** Available in v1.125.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.directmail.Receivers("example",
            receivers_alias="tf-vme8@onaliyun.com",
            receivers_name="vme8")
        ```

        ## Import

        Direct Mail Receivers can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:directmail/receivers:Receivers example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: The description of receivers and 1-50 characters in length.
        :param pulumi.Input[str] receivers_alias: The alias of receivers. Must email address and less than 30 characters in length.
        :param pulumi.Input[str] receivers_name: The name of the resource. The length that cannot be repeated is 1-30 characters.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ReceiversArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Direct Mail Receivers resource.

        For information about Direct Mail Receivers and how to use it, see [What is Direct Mail Receivers](https://www.alibabacloud.com/help/en/doc-detail/29414.htm).

        > **NOTE:** Available in v1.125.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.directmail.Receivers("example",
            receivers_alias="tf-vme8@onaliyun.com",
            receivers_name="vme8")
        ```

        ## Import

        Direct Mail Receivers can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:directmail/receivers:Receivers example <id>
        ```

        :param str resource_name: The name of the resource.
        :param ReceiversArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ReceiversArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 receivers_alias: Optional[pulumi.Input[str]] = None,
                 receivers_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ReceiversArgs.__new__(ReceiversArgs)

            __props__.__dict__["description"] = description
            if receivers_alias is None and not opts.urn:
                raise TypeError("Missing required property 'receivers_alias'")
            __props__.__dict__["receivers_alias"] = receivers_alias
            if receivers_name is None and not opts.urn:
                raise TypeError("Missing required property 'receivers_name'")
            __props__.__dict__["receivers_name"] = receivers_name
            __props__.__dict__["status"] = None
        super(Receivers, __self__).__init__(
            'alicloud:directmail/receivers:Receivers',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[str]] = None,
            receivers_alias: Optional[pulumi.Input[str]] = None,
            receivers_name: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[int]] = None) -> 'Receivers':
        """
        Get an existing Receivers resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: The description of receivers and 1-50 characters in length.
        :param pulumi.Input[str] receivers_alias: The alias of receivers. Must email address and less than 30 characters in length.
        :param pulumi.Input[str] receivers_name: The name of the resource. The length that cannot be repeated is 1-30 characters.
        :param pulumi.Input[int] status: The status of the resource. `0` means uploading, `1` means upload completed.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ReceiversState.__new__(_ReceiversState)

        __props__.__dict__["description"] = description
        __props__.__dict__["receivers_alias"] = receivers_alias
        __props__.__dict__["receivers_name"] = receivers_name
        __props__.__dict__["status"] = status
        return Receivers(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of receivers and 1-50 characters in length.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="receiversAlias")
    def receivers_alias(self) -> pulumi.Output[str]:
        """
        The alias of receivers. Must email address and less than 30 characters in length.
        """
        return pulumi.get(self, "receivers_alias")

    @property
    @pulumi.getter(name="receiversName")
    def receivers_name(self) -> pulumi.Output[str]:
        """
        The name of the resource. The length that cannot be repeated is 1-30 characters.
        """
        return pulumi.get(self, "receivers_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[int]:
        """
        The status of the resource. `0` means uploading, `1` means upload completed.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetVpcEndpointZonesResult',
    'AwaitableGetVpcEndpointZonesResult',
    'get_vpc_endpoint_zones',
    'get_vpc_endpoint_zones_output',
]

@pulumi.output_type
class GetVpcEndpointZonesResult:
    """
    A collection of values returned by getVpcEndpointZones.
    """
    def __init__(__self__, endpoint_id=None, id=None, ids=None, output_file=None, status=None, zones=None):
        if endpoint_id and not isinstance(endpoint_id, str):
            raise TypeError("Expected argument 'endpoint_id' to be a str")
        pulumi.set(__self__, "endpoint_id", endpoint_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if zones and not isinstance(zones, list):
            raise TypeError("Expected argument 'zones' to be a list")
        pulumi.set(__self__, "zones", zones)

    @property
    @pulumi.getter(name="endpointId")
    def endpoint_id(self) -> str:
        return pulumi.get(self, "endpoint_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def zones(self) -> Sequence['outputs.GetVpcEndpointZonesZoneResult']:
        return pulumi.get(self, "zones")


class AwaitableGetVpcEndpointZonesResult(GetVpcEndpointZonesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetVpcEndpointZonesResult(
            endpoint_id=self.endpoint_id,
            id=self.id,
            ids=self.ids,
            output_file=self.output_file,
            status=self.status,
            zones=self.zones)


def get_vpc_endpoint_zones(endpoint_id: Optional[str] = None,
                           output_file: Optional[str] = None,
                           status: Optional[str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetVpcEndpointZonesResult:
    """
    This data source provides the Privatelink Vpc Endpoint Zones of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.111.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    example = alicloud.privatelink.get_vpc_endpoint_zones(endpoint_id="ep-gw8boxxxxx")
    pulumi.export("firstPrivatelinkVpcEndpointZoneId", example.zones[0].id)
    ```


    :param str endpoint_id: The ID of the Vpc Endpoint.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str status: The Status of Vpc Endpoint Zone..
    """
    __args__ = dict()
    __args__['endpointId'] = endpoint_id
    __args__['outputFile'] = output_file
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:privatelink/getVpcEndpointZones:getVpcEndpointZones', __args__, opts=opts, typ=GetVpcEndpointZonesResult).value

    return AwaitableGetVpcEndpointZonesResult(
        endpoint_id=__ret__.endpoint_id,
        id=__ret__.id,
        ids=__ret__.ids,
        output_file=__ret__.output_file,
        status=__ret__.status,
        zones=__ret__.zones)


@_utilities.lift_output_func(get_vpc_endpoint_zones)
def get_vpc_endpoint_zones_output(endpoint_id: Optional[pulumi.Input[str]] = None,
                                  output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                  status: Optional[pulumi.Input[Optional[str]]] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetVpcEndpointZonesResult]:
    """
    This data source provides the Privatelink Vpc Endpoint Zones of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.111.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    example = alicloud.privatelink.get_vpc_endpoint_zones(endpoint_id="ep-gw8boxxxxx")
    pulumi.export("firstPrivatelinkVpcEndpointZoneId", example.zones[0].id)
    ```


    :param str endpoint_id: The ID of the Vpc Endpoint.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str status: The Status of Vpc Endpoint Zone..
    """
    ...
